import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:progamification/src/controllers/leader_board.dart';
import 'package:get/get.dart';
import 'package:progamification/src/services/sas_token.service.dart';
import 'package:progamification/src/utilities/helper.dart';
import 'package:google_fonts/google_fonts.dart';

class Rewards extends StatefulWidget {
  const Rewards({super.key});

  @override
  State<Rewards> createState() => _RewardsState();
}

class _RewardsState extends State<Rewards> {
  LeaderBoardController leaderBoardController =
      Get.find<LeaderBoardController>();
  SasTokenService sasTokenService = Get.find<SasTokenService>();
  String sasToken = "";

  @override
  initState() {
    super.initState();
    sasTokenService.getSasToken().then((value) {
      setState(() {
        sasToken = value.toString();
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    var userRewards = leaderBoardController.userRewards['userRewards']
        as Map<String, dynamic>;
    var rewardGroupNames = userRewards.keys.toList();

    return Column(children: [
      Container(
          margin: const EdgeInsets.only(
              top: 20.0, left: 20.0, right: 10.0, bottom: 20.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceBetween,
            children: [
              Text(
                "Earned badges",
                style: TextStyle(
                    fontSize: 19,
                    color: Colors.black,
                    fontWeight: FontWeight.w700,
                    fontFamily: GoogleFonts.plusJakartaSans().fontFamily),
              ),
              TextButton(
                  onPressed: () {
                    // Action to perform when button is pressed
                  },
                  child: Flex(
                    direction: Axis.horizontal,
                    crossAxisAlignment: CrossAxisAlignment.center,
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [
                      Text(
                        "View all badges",
                        style: TextStyle(
                            fontSize: 17,
                            color: Colors.black,
                            fontWeight: FontWeight.w700,
                            fontFamily:
                                GoogleFonts.plusJakartaSans().fontFamily),
                      ),
                      const SizedBox(width: 3),
                      const Icon(
                        Icons.arrow_forward_ios_rounded,
                        size: 15,
                        color: Colors.black,
                      )
                    ],
                  ))
            ],
          )),
      Column(
          children: rewardGroupNames
              .map((e) => getRewardsGroup(e, userRewards[e]))
              .toList())
    ]);
  }

  Widget getRewardsGroup(String title, List rewards) {
    return Column(
      children: [
        Align(
          alignment: Alignment.centerLeft,
        ),
        SizedBox(
            // height: 300,
            child: SingleChildScrollView(
                scrollDirection: Axis.vertical,
                child: Column(
                    children: rewards
                        .map((e) => getRewardItem(e['value'], e['sourceImgUrl'],
                            e['attained'] as bool))
                        .toList())))
      ],
    );
  }

  Widget getRewardItem(String title, String sourceImgUrl, bool isAttained) {
    return Align(
      alignment: Alignment.centerLeft,
      child: Row(children: [
        const SizedBox(height: 60),
        Opacity(
            opacity: isAttained ? 1.0 : 0.3,
            child: Container(
              width: 40,
              height: 40,
              margin: const EdgeInsets.only(left: 20.0, right: 2.0),
              padding: EdgeInsets.all(3.0),
              decoration: BoxDecoration(
                shape: BoxShape.circle,
                border: Border.all(
                  color: Color.fromARGB(255, 132, 220, 223),
                  width: 1.5,
                ),
              ),
              child: ClipOval(
                  child: CachedNetworkImage(
                key: UniqueKey(),
                imageUrl: sourceImgUrl + sasToken,
                width: 60.0,
                height: 60.0,
                fit: BoxFit.cover,
                placeholder: (context, url) => Container(
                  child: Image.asset(
                    "assets/icons/no-reward.png",
                    package: "progamification",
                  ),
                ),
                errorWidget: (context, url, error) => Container(
                  child: Image.asset(
                    "assets/icons/no-reward.png",
                    package: "progamification",
                  ),
                ),
              )),
            )),
        Padding(
          padding: const EdgeInsets.all(8.0),
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Text(capitalizeFirst(title),
                  style: TextStyle(
                      color: Colors.black,
                      fontWeight: FontWeight.w600,
                      fontSize: 16,
                      fontFamily: GoogleFonts.plusJakartaSans().fontFamily)),
              Text('Count :${isAttained ? '1' : '0'}',
                  style: TextStyle(
                      color: Colors.grey,
                      fontWeight: FontWeight.w500,
                      fontSize: 14,
                      fontFamily: GoogleFonts.plusJakartaSans().fontFamily))
            ],
          ),
        )
      ]),
    );
  }
}
